@@ -152,6 +152,14 @@ def upload_file():
     rsp.data = json.dumps({"procCode": 200})
     return rsp
 
+@mock_app.route("/upload_file/1", methods=["POST"])
+def upload_file1():
+    file = request.files['file']
+    file.save(os.path.join(os.path.dirname(__file__), "aiai", "upload_target.txt"))
+    rsp = base_json_response()
+    rsp.data = json.dumps({"procCode": 200})
+    return rsp
+
 
 @mock_app.route("/test_headers", methods=["GET"])
 def headers_tester():
@@ -160,7 +168,7 @@ def headers_tester():
     return rsp
 
 
-@mock_app.route("/company/<int:company_id>", methods=["GET"])
+@mock_app.route("/company/<int:company_id>", methods=["GET", "POST", "PUT", "DELETE"])
 def company(company_id):
     rsp = base_json_response()
     ret = list(filter(lambda c: c.get("id") == company_id, __mock_data["companies"]))[0]
